==> libreoffice-still-sdk-24.8.7-1-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.js <==
var servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange =
[
    [ "XPropertySet", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "XNamed", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#a06d9bde12d6408506b7a64e0e0d1408a", null ],
    [ "XCellRangeReferrer", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#aab7706bd0d8d10d44ac3c1d3b27af60e", null ],
    [ "XDatabaseRange", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#ae18754a27c9352fde63d0753a039f8a7", null ],
    [ "XRefreshable", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#abad65f33e0c30489f58a423e7ef907aa", null ],
    [ "AutoFilter", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#a036fcb002440abd5a92e7438bd638a61", null ],
    [ "ContainsHeader", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#a5065e7c42974615d07286e452e171dc2", null ],
    [ "FilterCriteriaSource", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#aa0cb852493408f207c840e051030900f", null ],
    [ "FromSelection", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#a7b22dfd47a05499327637898b2eae540", null ],
    [ "KeepFormats", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#ac34b74170aee53aa1f3898b38f5ac393", null ],
    [ "MoveCells", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#a71fe1dfd76fd7f9fb780e560f692cf00", null ],
    [ "RefreshPeriod", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#a84d65c48a2751fa526d687a0257d215e", null ],
    [ "StripData", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#a7fe75195e73b24e0e5df4fbe00e3a0c6", null ],
    [ "TokenIndex", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#aee82d26f89c26d9ec2530b7527c91574", null ],
    [ "TotalsRow", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#a07afacb63173eccba59e028e6fb42295", null ],
    [ "UseFilterCriteriaSource", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#a6574f499f5121ac67aa40c8e917af856", null ]
];

==> libreoffice-still-sdk-25.2.7-6-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.js <==
var servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange =
[
    [ "com::sun::star::beans::XPropertySet", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "com::sun::star::container::XNamed", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#a06d9bde12d6408506b7a64e0e0d1408a", null ],
    [ "com::sun::star::sheet::XCellRangeReferrer", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#aab7706bd0d8d10d44ac3c1d3b27af60e", null ],
    [ "com::sun::star::sheet::XDatabaseRange", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#ae18754a27c9352fde63d0753a039f8a7", null ],
    [ "com::sun::star::util::XRefreshable", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#abad65f33e0c30489f58a423e7ef907aa", null ],
    [ "AutoFilter", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#a036fcb002440abd5a92e7438bd638a61", null ],
    [ "ContainsHeader", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#a5065e7c42974615d07286e452e171dc2", null ],
    [ "FilterCriteriaSource", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#aa0cb852493408f207c840e051030900f", null ],
    [ "FromSelection", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#a7b22dfd47a05499327637898b2eae540", null ],
    [ "KeepFormats", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#ac34b74170aee53aa1f3898b38f5ac393", null ],
    [ "MoveCells", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#a71fe1dfd76fd7f9fb780e560f692cf00", null ],
    [ "RefreshPeriod", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#a84d65c48a2751fa526d687a0257d215e", null ],
    [ "StripData", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#a7fe75195e73b24e0e5df4fbe00e3a0c6", null ],
    [ "TokenIndex", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#aee82d26f89c26d9ec2530b7527c91574", null ],
    [ "TotalsRow", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#a07afacb63173eccba59e028e6fb42295", null ],
    [ "UseFilterCriteriaSource", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#a6574f499f5121ac67aa40c8e917af856", null ]
];
